@@ -25,20 +25,10 @@ def main():
         "input_file",
         help="Path to a file containing a Python program for which the CFG must be generated",
     )
-    parser.add_argument(
-        "--short", help="Shorten all strings above 20 characters", action="store_true"
-    )
-    parser.add_argument(
-        "--no_edge_labels",
-        help="Path to a file containing a Python program for which the CFG must be generated",
-        action="store_false",
-    )
 
     args = parser.parse_args()
     cfg_name = args.input_file.split("/")[-1]
-    cfg = CFGBuilder(args.short, args.no_edge_labels).build_from_file(
-        cfg_name, args.input_file
-    )
+    cfg = CFGBuilder().build_from_file(cfg_name, args.input_file)
 
     # Some options for wrapping:
     # cfg.build_visual(cfg_name[:-3] + '_cfg', format='pdf', calls=True)
