@@ -6,12 +6,23 @@ Control flow graph builder.
 """
 # Aurelien Coet, 2018.
 
-import ast
-from .model import Block, Link, CFG
-
 from typing import List, Optional
 import ast  # type: ignore
-from _ast import Assign, AugAssign, Call, ClassDef, Compare, Expr, FunctionDef, If, Module, Return, stmt, While, Yield  # type: ignore
+from _ast import (
+    Assign,
+    AugAssign,
+    Call,
+    ClassDef,
+    Compare,
+    Expr,
+    FunctionDef,
+    If,
+    Module,
+    Return,
+    stmt,
+    While,
+    Yield,
+)  # type: ignore
 from .model import Block, Link, CFG
 
 
@@ -77,10 +88,6 @@ class CFGBuilder(ast.NodeVisitor):
     a program's AST and iteratively build the corresponding CFG.
     """
 
-    def __init__(self, short: bool = False, label_edges: bool = True):
-        self.isShort = short
-        self.labelEdges = label_edges
-
     # ---------- CFG building methods ---------- #
     def build(
         self, name: str, tree: Module, asynchr: bool = False, entry_id: int = 0
@@ -100,9 +107,7 @@ class CFGBuilder(ast.NodeVisitor):
         Returns:
             The CFG produced from the AST.
         """
-        self.cfg = CFG(
-            name, asynchr=asynchr, short=self.isShort, label_edges=self.labelEdges
-        )
+        self.cfg = CFG(name, asynchr=asynchr)
         # Tracking of the current block while building the CFG.
         self.current_id = entry_id
         self.current_block = self.new_block()
@@ -214,7 +219,7 @@ class CFGBuilder(ast.NodeVisitor):
         # A new sub-CFG is created for the body of the class definition and
         # added to the class CFGs of the current CFG.
         class_body = ast.Module(body=node.body)
-        class_builder = CFGBuilder(short=self.isShort, label_edges=self.labelEdges)
+        class_builder = CFGBuilder()
         self.cfg.classcfgs[node.name] = class_builder.build(
             node.name, class_body, asynchr, self.current_id
         )
@@ -234,7 +239,7 @@ class CFGBuilder(ast.NodeVisitor):
         # A new sub-CFG is created for the body of the function definition and
         # added to the function CFGs of the current CFG.
         func_body = ast.Module(body=node.body)
-        func_builder = CFGBuilder(short=self.isShort, label_edges=self.labelEdges)
+        func_builder = CFGBuilder()
         self.cfg.functioncfgs[node.name] = func_builder.build(
             node.name, func_body, asynchr, self.current_id
         )
@@ -299,10 +304,10 @@ class CFGBuilder(ast.NodeVisitor):
                 func_name = visit_func(node.value)
                 func_name += "." + node.attr
                 return func_name
-            elif type(node) == ast.Str:
-                return node.s
             elif type(node) == ast.Subscript:
                 return node.value.id
+            elif type(node) == ast.Constant:
+                return node.value
 
         func = node.func
         func_name = visit_func(func)
