@@ -11,8 +11,6 @@ import ast  # type: ignore
 from _ast import Compare  # type: ignore
 import astor  # type: ignore
 import graphviz as gv  # type: ignore
-
-import re
 from graphviz.dot import Digraph  # type: ignore
 
 
@@ -159,13 +157,7 @@ class CFG(object):
     CFG).
     """
 
-    def __init__(
-        self,
-        name: str,
-        asynchr: bool = False,
-        short: bool = False,
-        label_edges: bool = True,
-    ) -> None:
+    def __init__(self, name: str, asynchr: bool = False) -> None:
         assert type(name) == str, "Name of a CFG must be a string"
         assert type(asynchr) == bool, "Async must be a boolean value"
         # Name of the function or module being represented.
@@ -197,8 +189,6 @@ class CFG(object):
             "input": "#afeeee",  # Pale Turquoise
             "default": "#FFFB81",
         }  # Pale Yellow
-        self.isShort = short
-        self.labelEdges = label_edges
 
     def __str__(self) -> str:
         return "CFG for {}".format(self.name)
@@ -269,7 +259,7 @@ class CFG(object):
         if block.id in visited:
             return
 
-        original_nodelabel = block.get_source()  # label = nodelabel
+        nodelabel = block.get_source()  # label = nodelabel
         # Use the first statement to find out what's in the node
         # Just convert it to a string for simplicity
         # This saves us from parsing the entire label and having to handle strings
@@ -281,7 +271,7 @@ class CFG(object):
         # _ast.Expr is the generic case (think base-level AST node),
         # _ast.Assign is also unused here in case we want to highlight them differently
         if "_ast.ClassDef" in node_type:
-            original_nodelabel = original_nodelabel.splitlines()[0] + " ...\n"
+            nodelabel = nodelabel.splitlines()[0] + " ...\n"
         if "_ast.If" in node_type:
             nodeshape = self.shapes["if"]
             nodecolor = self.colors["if"]
@@ -294,29 +284,10 @@ class CFG(object):
         else:
             # Left-align all remaining blocks
             tmp = ""
-            for line in original_nodelabel.splitlines():
+            for line in nodelabel.splitlines():
                 line += "\l"
                 tmp += line
-            original_nodelabel = tmp
-        nodelabel = ""
-        if (
-            self.isShort
-            and "_ast.ClassDef" not in node_type
-            and "_ast.FunctionDef" not in node_type
-            and "_ast.If" not in node_type
-            and "_ast.While" not in node_type
-        ):
-            sub_pattern = r"""(\"|')                # Group 1: " or '
-                              (?=[^\"'\r\n]{20,})   # Enforce min length of 20
-                              ([^\"'\r\n]{,20})     # Group 2: Words that stay
-                              ([^\"'\r\n]{,9999})   # Group 3: Shorten these 
-                              (\"|')"""  # Group 4: " or '
-            original_nodelabel = original_nodelabel.replace("\l", "\n")
-            for line in original_nodelabel.splitlines():
-                tmp_line = re.sub(sub_pattern, r"\1\2...\4", line, flags=re.VERBOSE)
-                nodelabel += tmp_line + "\l"
-        else:
-            nodelabel = original_nodelabel
+            nodelabel = tmp
 
         graph.node(
             str(block.id),
@@ -346,6 +317,7 @@ class CFG(object):
                         },
                     )
                     graph.edge(str(block.id) + "_input", str(block.id))
+                    # _attributes={'style': 'dashed'})
                 else:
                     line += "\l"
                     tmp += line
@@ -360,13 +332,10 @@ class CFG(object):
                 },
             )
 
-            edgelabel = "calls"
-            if not self.labelEdges:
-                edgelabel = ""
             graph.edge(
                 str(block.id),
                 calls_node,
-                label=edgelabel,
+                label="calls",
                 _attributes={"style": "dashed"},
             )
 
@@ -375,7 +344,6 @@ class CFG(object):
             edgecolor = "black"
             self._visit_blocks(graph, exit.target, visited, calls=calls)
             edgelabel = exit.get_exitcase().strip()
-            # graph.edge(str(block.id), str(exit.target.id), label=edgelabel)
             if (
                 ("_ast.If" in node_type)
                 or ("_ast.For" in node_type)
@@ -386,8 +354,7 @@ class CFG(object):
                     edgecolor = "green"
             if "_ast.ClassDef" in node_type:
                 insert_edge = False
-            if not self.labelEdges:
-                edgelabel = ""
+
             graph.edge(
                 str(block.id),
                 str(exit.target.id),
@@ -451,7 +418,8 @@ class CFG(object):
                 to_visit.append(exit_.target)
             yield block
 
-        for classcfg in self.functioncfgs.values():
-            yield from classcfg
+        for subcfg in self.classcfgs.values():
+            yield from subcfg
+
         for subcfg in self.functioncfgs.values():
             yield from subcfg
